@@ -44,6 +44,8 @@ from pyworkflow.utils.properties import Icon
 
 
 class ProjectsView(tk.Frame):
+    _PROJ_CONTAINER = "projectsframe"
+
     def __init__(self, parent, windows, **args):
         tk.Frame.__init__(self, parent, bg='white', **args)
         self.windows = windows
@@ -107,25 +109,19 @@ class ProjectsView(tk.Frame):
         r = 0
         text.setReadOnly(False)
         text.clear()
-        parent = tk.Frame(text, bg='white')
+        parent = tk.Frame(text, bg='white', name=self._PROJ_CONTAINER)
         parent.columnconfigure(0, weight=1)
         colors = ['white', '#EAEBFF']
         for i, p in enumerate(self.manager.listProjects()):
             try:
-                project = self.manager.loadProject(p.getName(), chdir=False, loadAllConfig=False)
-                project.closeMapper()
                 # Add creation time to project info
-                p.cTime = project.getCreationTime()
                 # Add if it's a link
-                p.isLink = project.isLink()
+                p.index = "index%s" % i
 
                 # Consider the filter
                 if not self._doesProjectMatchFilter(p):
                     continue
 
-                # If it's a link, get the linked folder
-                if p.isLink:
-                    p.linkedFolder = os.path.realpath(project.path)
                 frame = self.createProjectLabel(parent, p, color=colors[i % 2])
                 frame.grid(row=r, column=0, padx=10, pady=5, sticky='new')
                 r += 1
@@ -137,7 +133,7 @@ class ProjectsView(tk.Frame):
         text.setReadOnly(True)
 
     def createProjectLabel(self, parent, projInfo, color):
-        frame = tk.Frame(parent, bg=color)
+        frame = tk.Frame(parent, bg=color, name=projInfo.index)
         # ROW1
         # Project name
         label = tk.Label(frame, text=projInfo.projName, anchor='nw', bg=color,
@@ -154,24 +150,24 @@ class ProjectsView(tk.Frame):
         # Delete action
         delLabel = tk.Label(frame, text=Message.LABEL_DELETE_PROJECT, font=self.projDelFont, bg=color, cursor='hand1')
         delLabel.grid(row=1, column=1, padx=10)
-        delLabel.bind('<Button-1>', lambda e: self.deleteProject(projInfo.projName))
+        delLabel.bind('<Button-1>', lambda e: self.deleteProject(projInfo))
         # Rename action
         mvLabel = tk.Label(frame, text=Message.LABEL_RENAME_PROJECT, font=self.projDelFont, bg=color, cursor='hand1')
         mvLabel.grid(row=1, column=2)
         mvLabel.bind('<Button-1>', lambda e: self.renameProject(projInfo.projName))
 
         # ROW3
-        if projInfo.isLink:
-            linkMsg = 'link --> ' + projInfo.linkedFolder
+        if projInfo.isLink():
+            linkMsg = 'link --> ' + projInfo.realPath()
             lblLink = tk.Label(frame, text=linkMsg, font=self.projDateFont, bg=color, fg='grey', justify=tk.LEFT)
             lblLink.grid(row=2, column=0, columnspan=3, sticky='w')
 
         return frame
 
     def createNewProject(self, projName, projLocation):
-        self.manager.createProject(projName, location=projLocation)
+        proj = self.manager.createProject(projName, location=projLocation)
         self.createProjectList(self.text)
-        self.openProject(projName)
+        self.openProject(proj.getShortName())
 
     def _onCreateProject(self, e=None):
         projWindow = ProjectCreateWindow("Create project", self)
@@ -207,11 +203,17 @@ class ProjectsView(tk.Frame):
         script = pw.join(pw.APPS, 'pw_project.py')
         Popen([pw.PYTHON, script, projName])
 
-    def deleteProject(self, projName):
+    def deleteProject(self, projInfo):
+
+        projName = projInfo.projName
+
         if askYesNo(Message.TITLE_DELETE_PROJECT,
                     "Project *%s*. " % projName + Message.MESSAGE_DELETE_PROJECT, self.root):
             self.manager.deleteProject(projName)
-            self.createProjectList(self.text)
+
+            #Delete the frame
+            self.text.children[self._PROJ_CONTAINER].children[projInfo.index].grid_forget()
+
 
     def renameProject(self, projName):
         newName = askString("Rename project %s" % projName, "Enter new name:", self.root)
@@ -250,29 +252,32 @@ class ProjectCreateWindow(Window):
         content.config(bg='white')
         content.grid(row=0, column=0, sticky='news', padx=5, pady=5)
 
+        # Info line
+        labelInfo = tk.Label(content, text="Spaces will be replaced by underscores!", bg='white', bd=0)
+        labelInfo.grid(row=0, sticky=tk.W, padx=5, pady=5)
         #  Project name line
         labelName = tk.Label(content, text=Message.LABEL_PROJECT + ' name', bg='white', bd=0)
-        labelName.grid(row=0, sticky=tk.W, padx=5, pady=5)
+        labelName.grid(row=1, sticky=tk.W, padx=5, pady=5)
         entryName = tk.Entry(content, bg=cfgEntryBgColor, width=20, textvariable=self.projName)
-        entryName.grid(row=0, column=1, columnspan=2, sticky=tk.W, padx=5, pady=5)
+        entryName.grid(row=1, column=1, columnspan=2, sticky=tk.EW, padx=5, pady=5)
         entryName.bind("<Return>", self._create)
         entryName.bind("<KP_Enter>", self._create)
         # Project location line
         labelLocation = tk.Label(content, text=Message.LABEL_PROJECT + ' location', bg='white', bd=0)
-        labelLocation.grid(row=1, column=0, sticky='nw', padx=5, pady=5)
+        labelLocation.grid(row=2, column=0, sticky='nw', padx=5, pady=5)
 
         self.entryBrowse = tk.Entry(content, bg=cfgEntryBgColor, width=40, textvariable=self.projLocation)
-        self.entryBrowse.grid(row=1, column=1, sticky='nw', padx=5, pady=5)
+        self.entryBrowse.grid(row=2, column=1, sticky='nw', padx=5, pady=5)
         self.btnBrowse = IconButton(content, 'Browse', Icon.ACTION_BROWSE,
                                     highlightthickness=0, command=self._browsePath)
-        self.btnBrowse.grid(row=1, column=2, sticky='e', padx=5, pady=5)
+        self.btnBrowse.grid(row=2, column=2, sticky='e', padx=5, pady=5)
 
         self.initial_focus = entryName
         self.initial_focus.focus()
 
         btnFrame = tk.Frame(content)
         btnFrame.columnconfigure(0, weight=1)
-        btnFrame.grid(row=2, column=0, sticky='sew', padx=5, pady=(0, 5), columnspan=2)
+        btnFrame.grid(row=3, column=0, sticky='sew', padx=5, pady=(0, 5), columnspan=2)
         btnFrame.config(bg='white')
 
         # Create buttons
